@@ -18,6 +18,10 @@ Release logic:
 13. git push
 """
 
-__version__ = '1.2'
+__version__ = '1.2.1'
 
-default_app_config = 'sass_processor.apps.SassProcessorConfig'
+import django
+
+if django.VERSION < (3, 2):
+    # https://docs.djangoproject.com/en/dev/releases/3.2/#whats-new-3-2
+    default_app_config = 'sass_processor.apps.SassProcessorConfig'
